@@ -1,6 +1,5 @@
 import os
 import time
-from enum import StrEnum
 
 import gitlab
 from custom_python_logger import get_logger
@@ -15,16 +14,17 @@ from gitlab.v4.objects import (
     ProjectPipeline,
     ProjectTag,
 )
+from python_base_toolkit.base_structures.base_enum import BaseStrEnum
 
 
-class GitLabStatus(StrEnum):
+class GitLabStatus(BaseStrEnum):
     OPEN = "opened"
     CLOSED = "closed"
     MERGED = "merged"
     LOCKED = "locked"
 
 
-class GitLabPipelineStatus(StrEnum):
+class GitLabPipelineStatus(BaseStrEnum):
     SUCCESS = "success"
     FAILED = "failed"
     CANCELED = "canceled"
@@ -164,8 +164,21 @@ class GitLabMergeRequestService:
         self.gitlab = gitlab_client
         self.project = project
 
-    def list(self, per_page: int = 20, iterator: bool = False, get_all: bool = False) -> list[ProjectMergeRequest]:
-        return self.project.mergerequests.list(per_page=per_page, iterator=iterator, get_all=get_all)
+    def list(
+        self,
+        per_page: int = 20,
+        iterator: bool = False,
+        get_all: bool = False,
+        state: GitLabStatus | None = None,
+        target_branch: str | None = None,
+    ) -> list[ProjectMergeRequest]:
+        return self.project.mergerequests.list(
+            per_page=per_page,
+            iterator=iterator,
+            get_all=get_all,
+            state=state.value if state else None,
+            target_branch=target_branch,
+        )
 
     def get_info(self, mr_number: int) -> ProjectMergeRequest:
         return self.project.mergerequests.get(mr_number)
